==> sadad_payment_flutter-0.0.1.tar.gz: lib/commonWidgets.dart <==
import 'package:flutter/material.dart';

class CommonWidgets {
  static Color primaryColor = const Color(0xFFA02058);
  static Widget commonUnderLineTextField({required String labelText, Widget? prefix, Widget? suffixIcon,Color? themeColor}) {
    return TextFormField(
        cursorColor: themeColor??primaryColor,
        style: const TextStyle(color: Colors.black, fontSize: 15, fontWeight: FontWeight.w400),
        decoration: InputDecoration(
            helperText: "",
            contentPadding: const EdgeInsets.only(bottom: 3),
            prefix: prefix,
            suffixIcon: suffixIcon ?? SizedBox(),
            suffixIconConstraints: BoxConstraints.tightFor(),
            alignLabelWithHint: true,
            labelStyle: TextStyle(
              color: const Color(0xFF000000).withOpacity(0.5),
            ),
            labelText: labelText,
            border: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            errorBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            enabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            focusedBorder: UnderlineInputBorder(borderSide: BorderSide(color: themeColor??primaryColor, width: 1.5)),
            disabledBorder:
            UnderlineInputBorder(borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3)))));
  }

  static Widget commonTextField({required String labelText, Widget? prefix, Widget? suffixIcon,Color? themeColor}) {
    return TextFormField(
        cursorColor: themeColor?? primaryColor,
        style: const TextStyle(color: Colors.black, fontSize: 15, fontWeight: FontWeight.w400),
        decoration: InputDecoration(
            helperText: "",
            contentPadding: const EdgeInsets.only(left: 12),
            suffixIconConstraints: BoxConstraints.tightFor(),
            alignLabelWithHint: true,
            labelStyle: TextStyle(
              color: const Color(0xFF000000).withOpacity(0.5),
            ),
            labelText: labelText,
            border: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            errorBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            enabledBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            focusedBorder: OutlineInputBorder(
                borderSide: BorderSide(color: themeColor??primaryColor, width: 1.5), borderRadius: BorderRadius.circular(10)),
            disabledBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3)),
                borderRadius: BorderRadius.circular(10))));
  }
}

==> sadad_payment_flutter-0.0.11.tar.gz: lib/commonWidgets.dart <==
import 'package:flutter/material.dart';

class CommonWidgets {
  static Color primaryColor = const Color(0xFFA02058);
  static Widget commonUnderLineTextField(
      {required String labelText, bool? isObscure, Widget? prefix, Widget? suffixIcon, Color? themeColor}) {
    return TextFormField(
        obscureText: isObscure ?? false,
        cursorColor: themeColor ?? primaryColor,
        style: const TextStyle(color: Colors.black, fontSize: 15, fontWeight: FontWeight.w400),
        decoration: InputDecoration(
            helperText: "",
            contentPadding: const EdgeInsets.only(bottom: 3),
            prefix: prefix,
            suffixIcon: suffixIcon ?? SizedBox(),
            suffixIconConstraints: BoxConstraints.tightFor(),
            alignLabelWithHint: true,
            labelStyle: TextStyle(
              color: const Color(0xFF000000).withOpacity(0.5),
            ),
            labelText: labelText,
            border: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            errorBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            enabledBorder: UnderlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3), width: 1.5)),
            focusedBorder: UnderlineInputBorder(borderSide: BorderSide(color: themeColor ?? primaryColor, width: 1.5)),
            disabledBorder:
            UnderlineInputBorder(borderSide: BorderSide(color: const Color(0xFF000000).withOpacity(0.3)))));
  }

  static Widget commonTextField({required String labelText, Widget? prefix, Widget? suffixIcon, Color? themeColor,bool? obscure}) {
    return TextFormField(obscureText: obscure??false,
        cursorColor: themeColor ?? primaryColor,
        style: const TextStyle(color: Colors.black, fontSize: 15, fontWeight: FontWeight.w400),
        decoration: InputDecoration(
            helperText: "",
            contentPadding: const EdgeInsets.only(left: 12),
            alignLabelWithHint: true,
            labelStyle: TextStyle(
              color: const Color(0xFF000000).withOpacity(0.5),
            ),
            suffixIcon: suffixIcon ?? SizedBox(),
            suffixIconConstraints: BoxConstraints.tightFor(),
            labelText: labelText,
            border: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            errorBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            enabledBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3), width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            focusedBorder: OutlineInputBorder(
                borderSide: BorderSide(color: themeColor ?? primaryColor, width: 1.5),
                borderRadius: BorderRadius.circular(10)),
            disabledBorder: OutlineInputBorder(
                borderSide: BorderSide(color: const Color(0xFFDDDDDD).withOpacity(0.3)),
                borderRadius: BorderRadius.circular(10))));
  }
}
